==> istio-model-v1alpha3-6.2.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ReadinessProbeExecFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ReadinessProbeExecFluentImpl<A extends ReadinessProbeExecFluent<A>> extends BaseFluent<A> implements ReadinessProbeExecFluent<A>{
  public ReadinessProbeExecFluentImpl() {
  }
  public ReadinessProbeExecFluentImpl(ReadinessProbeExec instance) {
    this.withExec(instance.getExec()); 
  }
  private ExecHealthCheckConfigBuilder exec;
  
  /**
   * This method has been deprecated, please use method buildExec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ExecHealthCheckConfig getExec() {
    return this.exec!=null ?this.exec.build():null;
  }
  public ExecHealthCheckConfig buildExec() {
    return this.exec!=null ?this.exec.build():null;
  }
  public A withExec(ExecHealthCheckConfig exec) {
    _visitables.get("exec").remove(this.exec);
    if (exec!=null){ this.exec= new ExecHealthCheckConfigBuilder(exec); _visitables.get("exec").add(this.exec);} else { this.exec = null; _visitables.get("exec").remove(this.exec); } return (A) this;
  }
  public Boolean hasExec() {
    return this.exec != null;
  }
  public ReadinessProbeExecFluent.ExecNested<A> withNewExec() {
    return new ReadinessProbeExecFluentImpl.ExecNestedImpl();
  }
  public ReadinessProbeExecFluent.ExecNested<A> withNewExecLike(ExecHealthCheckConfig item) {
    return new ReadinessProbeExecFluentImpl.ExecNestedImpl(item);
  }
  public ReadinessProbeExecFluent.ExecNested<A> editExec() {
    return withNewExecLike(getExec());
  }
  public ReadinessProbeExecFluent.ExecNested<A> editOrNewExec() {
    return withNewExecLike(getExec() != null ? getExec(): new ExecHealthCheckConfigBuilder().build());
  }
  public ReadinessProbeExecFluent.ExecNested<A> editOrNewExecLike(ExecHealthCheckConfig item) {
    return withNewExecLike(getExec() != null ? getExec(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ReadinessProbeExecFluentImpl that = (ReadinessProbeExecFluentImpl) o;
    if (exec != null ? !exec.equals(that.exec) :that.exec != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(exec,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (exec != null) { sb.append("exec:"); sb.append(exec); }
    sb.append("}");
    return sb.toString();
  }
  class ExecNestedImpl<N> extends ExecHealthCheckConfigFluentImpl<ReadinessProbeExecFluent.ExecNested<N>> implements ReadinessProbeExecFluent.ExecNested<N>,Nested<N>{
    ExecNestedImpl(ExecHealthCheckConfig item) {
      this.builder = new ExecHealthCheckConfigBuilder(this, item);
    }
    ExecNestedImpl() {
      this.builder = new ExecHealthCheckConfigBuilder(this);
    }
    ExecHealthCheckConfigBuilder builder;
    public N and() {
      return (N) ReadinessProbeExecFluentImpl.this.withExec(builder.build());
    }
    public N endExec() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ReadinessProbeExecFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ReadinessProbeExecFluentImpl<A extends ReadinessProbeExecFluent<A>> extends BaseFluent<A> implements ReadinessProbeExecFluent<A>{
  public ReadinessProbeExecFluentImpl() {
  }
  public ReadinessProbeExecFluentImpl(ReadinessProbeExec instance) {
    if (instance != null) {
      this.withExec(instance.getExec());
    }
  }
  private ExecHealthCheckConfigBuilder exec;
  
  /**
   * This method has been deprecated, please use method buildExec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ExecHealthCheckConfig getExec() {
    return this.exec!=null ?this.exec.build():null;
  }
  public ExecHealthCheckConfig buildExec() {
    return this.exec!=null ?this.exec.build():null;
  }
  public A withExec(ExecHealthCheckConfig exec) {
    _visitables.get("exec").remove(this.exec);
    if (exec!=null){ this.exec= new ExecHealthCheckConfigBuilder(exec); _visitables.get("exec").add(this.exec);} else { this.exec = null; _visitables.get("exec").remove(this.exec); } return (A) this;
  }
  public Boolean hasExec() {
    return this.exec != null;
  }
  public ReadinessProbeExecFluentImpl.ExecNested<A> withNewExec() {
    return new ReadinessProbeExecFluentImpl.ExecNestedImpl();
  }
  public ReadinessProbeExecFluentImpl.ExecNested<A> withNewExecLike(ExecHealthCheckConfig item) {
    return new ReadinessProbeExecFluentImpl.ExecNestedImpl(item);
  }
  public ReadinessProbeExecFluentImpl.ExecNested<A> editExec() {
    return withNewExecLike(getExec());
  }
  public ReadinessProbeExecFluentImpl.ExecNested<A> editOrNewExec() {
    return withNewExecLike(getExec() != null ? getExec(): new ExecHealthCheckConfigBuilder().build());
  }
  public ReadinessProbeExecFluentImpl.ExecNested<A> editOrNewExecLike(ExecHealthCheckConfig item) {
    return withNewExecLike(getExec() != null ? getExec(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ReadinessProbeExecFluentImpl that = (ReadinessProbeExecFluentImpl) o;
    if (!java.util.Objects.equals(exec, that.exec)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(exec,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (exec != null) { sb.append("exec:"); sb.append(exec); }
    sb.append("}");
    return sb.toString();
  }
  class ExecNestedImpl<N> extends ExecHealthCheckConfigFluentImpl<ReadinessProbeExecFluentImpl.ExecNested<N>> implements ReadinessProbeExecFluentImpl.ExecNested<N>,Nested<N>{
    ExecNestedImpl(ExecHealthCheckConfig item) {
      this.builder = new ExecHealthCheckConfigBuilder(this, item);
    }
    ExecNestedImpl() {
      this.builder = new ExecHealthCheckConfigBuilder(this);
    }
    ExecHealthCheckConfigBuilder builder;
    public N and() {
      return (N) ReadinessProbeExecFluentImpl.this.withExec(builder.build());
    }
    public N endExec() {
      return and();
    }
    
  }
  
}
